<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'Forum van SPIP (privé en openbaar)',
	'forum_slogan' => 'Beheer van de privé en openbare SPIP forums',
];
